@@ -4,12 +4,18 @@ from thabala_cli.commands.utils.profile import get_profile
 
 
 def pause(args):
-    """Get users"""
+    """Pause service instance"""
     api_client = ApiClient(get_profile(args))
     api_client.pause_service_instance(args.service_instance_id)
 
 
 def resume(args):
-    """Get users"""
+    """Resume service instance"""
     api_client = ApiClient(get_profile(args))
     api_client.resume_service_instance(args.service_instance_id)
+
+
+def delete(args):
+    """Delete service instance"""
+    api_client = ApiClient(get_profile(args))
+    api_client.delete_service_instance(args.service_instance_id)
