@@ -12,11 +12,12 @@ log = logging.getLogger(__name__)
 class AuthByPassword(AuthBase):
     """Authenticate by user and password via the default Thabala backend database"""
 
-    def __init__(self, api_base_url, username, password):
+    def __init__(self, api_base_url, username, password, account_id):
         super().__init__(api_base_url)
 
         self._username = username
         self._password = password
+        self._account_id = account_id
 
     def authenticate(self):
         """User and password based authentication"""
@@ -28,6 +29,7 @@ class AuthByPassword(AuthBase):
                 headers=self._headers,
                 json={
                     "grant_type": "password",
+                    "account_id_or_name": self._account_id,
                     "username": self._username,
                     "password": self._password,
                 },
