@@ -7,6 +7,8 @@ import sys
 from collections import OrderedDict
 from configparser import _UNSET  # type: ignore
 from configparser import ConfigParser
+from configparser import DuplicateOptionError
+from configparser import DuplicateSectionError
 from configparser import NoOptionError
 from configparser import NoSectionError
 from typing import Dict
@@ -532,5 +534,9 @@ THABALA_CLI_CONFIG = get_thabala_cli_config(THABALA_HOME)
 
 TEST_CONFIG_FILE = get_thabala_cli_test_config(THABALA_HOME)
 
-conf = initialize_config()
-conf.validate()
+try:
+    conf = initialize_config()
+    conf.validate()
+except (DuplicateOptionError, DuplicateSectionError) as err:
+    log.error(err)
+    sys.exit(1)
