@@ -14,9 +14,13 @@ def partition(pred: Callable, iterable: Iterable):
 
 
 def raise_thabala_cli_api_exc(err: Exception, response_json: Dict = None) -> None:
+    title = None
     detail = None
 
     if response_json:
-        detail = response_json.get("detail")
+        title = response_json.get("title") or ""
+        detail = response_json.get("detail") or ""
 
-    raise ThabalaCliApiException(f"{err} - {detail}" if detail else err)
+    raise ThabalaCliApiException(
+        f"{err} - {title} - {detail}" if title or detail else err
+    )
